LoginClient

Struct LoginClient 

pub struct LoginClient(pub(crate) LoginClient);
Client for authenticating a user against the Identity API.

Obtain one via crate::auth::AuthClient::login.

Tuple Fields

0: LoginClient

Implementations

Source

impl LoginClient

pub async fn get_password_prelogin( &self, email: String, ) -> Result<PasswordPreloginResponse, BitwardenError>

Retrieves the data required before authenticating with a password.

pub async fn login_via_password( &self, request: PasswordLoginRequest, ) -> Result<LoginResponse, BitwardenError>

Authenticates a user via email and master password.

Derives the master password hash using the prelogin response, then sends the authentication request to obtain access tokens and vault keys.