pub struct LoginClient(pub(crate) LoginClient);Expand description
Client for authenticating a user against the Identity API.
Obtain one via crate::auth::AuthClient::login.
Tuple Fields
0: LoginClientImplementations
Sourceimpl LoginClient
impl LoginClient
Sourcepub async fn get_password_prelogin(
&self,
email: String,
) -> Result<PasswordPreloginResponse, BitwardenError>
pub async fn get_password_prelogin( &self, email: String, ) -> Result<PasswordPreloginResponse, BitwardenError>
Retrieves the data required before authenticating with a password.
Sourcepub async fn login_via_password(
&self,
request: PasswordLoginRequest,
) -> Result<LoginResponse, BitwardenError>
pub async fn login_via_password( &self, request: PasswordLoginRequest, ) -> Result<LoginResponse, BitwardenError>
Authenticates a user via email and master password.
Derives the master password hash using the prelogin response, then sends the authentication request to obtain access tokens and vault keys.